.unavailable[data-v-585f09e9],.dimmed[data-v-585f09e9]{opacity:.3}.hidden[data-v-585f09e9]{opacity:0}.play-button-overlay[data-v-585f09e9]{position:absolute;inset:0;display:flex;align-items:center;justify-content:center;pointer-events:none}.play-button-overlay .v-btn[data-v-585f09e9]{pointer-events:all}.hiresicon[data-v-585f09e9]{margin-top:5px;margin-right:15px;margin-left:15px;filter:invert(100%)}.hiresicondark[data-v-585f09e9]{margin-top:5px;margin-right:15px;margin-left:15px}.v-card.unavailable[data-v-bb3ba95c]{opacity:.3}.panel-item[data-v-bb3ba95c]{height:100%;padding:10px;border:none;border-style:none!important}.panel-item-checkbox[data-v-bb3ba95c]{position:absolute;width:100%;height:auto;left:0;right:0}.panel-item-details[data-v-bb3ba95c]{margin-top:10px;padding-left:0!important;padding-right:0!important;height:40px}.panel-item-actions[data-v-bb3ba95c]{padding:0;margin:10px 0 0;height:40px;min-height:unset!important}panel-item-details[data-v-bb3ba95c] .v-list-item__content{height:30px}.v-card--active[data-v-bb3ba95c]{background-color:red}.hiresicon[data-v-bb3ba95c]{margin-right:10px}.hiresiconinverted[data-v-bb3ba95c]{margin-right:10px;filter:invert(100%)}.col-2[data-v-1b37f451]{width:50%;max-width:50%;flex-basis:50%;padding:8px}.col-3[data-v-1b37f451]{width:33.3%;max-width:33.3%;flex-basis:33.3%;padding:8px}.col-4[data-v-1b37f451]{width:25%;max-width:25%;flex-basis:25%;padding:8px}.col-5[data-v-1b37f451]{width:20%;max-width:20%;flex-basis:20%;padding:8px}.col-6[data-v-1b37f451]{width:16.6%;max-width:16.6%;flex-basis:16.6%;padding:8px}.col-7[data-v-1b37f451]{width:14.2%;max-width:14.2%;flex-basis:14.2%;padding:8px}.col-8[data-v-1b37f451]{width:12.5%;max-width:12.5%;flex-basis:12.5%;padding:8px}.col-9[data-v-1b37f451]{width:11.1%;max-width:11.1%;flex-basis:11.1%;padding:8px}
