import{I as c}from"./ItemsListing-Dd2XfzXe.js";import{I as f,_ as v}from"./ProviderDetails.vue_vue_type_style_index_0_lang-IDW8d92N.js";import{c as s,J as h}from"./index-HFEfURXv.js";import{d as I,r as w,w as y,b as V,e as m,H as g,D as n,I as p,f as k}from"./lucide-sS6c3snl.js";import"./Container-LvH0QRIT.js";import"./index-kQIztB-E.js";import"./vuetify-ffr1lJCG.js";import"./Toolbar-BVGuuXVD.js";import"./vue-router-CDtPtBGv.js";import"./Button-Dcdmvtuy.js";import"./ListItem-C-8fkaRP.js";import"./NowPlayingBadge.vue_vue_type_style_index_0_lang-Bgx2hOXi.js";import"./MediaItemThumb-D4l-2_B4.js";import"./vue-i18n-h4EBIvPF.js";import"./PanelviewItemCompact-PrcYkefq.js";import"./userPreferences-CRnDt302.js";import"./marquee_text_sync-BgCfvceK.js";import"./qrcode-Dq-byqKu.js";import"./marked-C0Rlrcoy.js";import"./color-BTziYnFN.js";import"./vueuse-B-HgI0gk.js";/* empty css            */import"./swiper-BtP4dEja.js";const O=I({__name:"RadioDetails",props:{itemId:{},provider:{}},setup(a){const t=a,e=w(),l=async function(){e.value=await s.getRadio(t.itemId,t.provider)};y(()=>t.itemId,r=>{r&&l()},{immediate:!0});const d=async function(r){const i=[];if(t.provider=="library"){const o=await s.getRadioVersions(t.itemId,t.provider);i.push(...o)}for(const o of h(e.value)){const u=await s.getRadioVersions(o.item_id,o.provider_instance);i.push(...u)}return i};return(r,i)=>(m(),V("section",null,[g(f,{item:e.value},null,8,["item"]),e.value?(m(),n(c,{key:0,itemtype:"radioversions","parent-item":e.value,"show-provider":!0,"show-favorites-only-filter":!1,"show-library":!1,"show-radio-number":!1,"show-duration":!1,"load-items":d,"sort-keys":["provider","sort_name"],title:r.$t("other_versions"),"hide-on-empty":!0,checksum:a.provider+a.itemId},null,8,["parent-item","title","checksum"])):p("",!0),i[0]||(i[0]=k("br",null,null,-1)),e.value?(m(),n(v,{key:1,"item-details":e.value},null,8,["item-details"])):p("",!0)]))}});export{O as default};
