import{I as f,_ as v}from"./ProviderDetails.vue_vue_type_style_index_0_lang-IDW8d92N.js";import{I}from"./ItemsListing-Dd2XfzXe.js";import{c as a,E as _}from"./index-HFEfURXv.js";import{d as h,r as m,w as b,o as w,a1 as y,b as k,e as r,H as E,D as p,I as n,F as D}from"./lucide-sS6c3snl.js";import"./Toolbar-BVGuuXVD.js";import"./vuetify-ffr1lJCG.js";import"./marquee_text_sync-BgCfvceK.js";import"./vue-router-CDtPtBGv.js";import"./MediaItemThumb-D4l-2_B4.js";import"./Container-LvH0QRIT.js";import"./index-kQIztB-E.js";import"./ListItem-C-8fkaRP.js";import"./Button-Dcdmvtuy.js";import"./vue-i18n-h4EBIvPF.js";import"./NowPlayingBadge.vue_vue_type_style_index_0_lang-Bgx2hOXi.js";import"./PanelviewItemCompact-PrcYkefq.js";import"./userPreferences-CRnDt302.js";import"./qrcode-Dq-byqKu.js";import"./marked-C0Rlrcoy.js";import"./color-BTziYnFN.js";import"./vueuse-B-HgI0gk.js";/* empty css            */import"./swiper-BtP4dEja.js";const R=h({__name:"PodcastDetails",props:{itemId:{},provider:{}},setup(l){const e=l,i=m(!1),t=m(),d=async function(){t.value=await a.getPodcast(e.itemId,e.provider)};b(()=>e.itemId,o=>{o&&d()},{immediate:!0}),w(()=>{const o=a.subscribe(_.MEDIA_ITEM_UPDATED,s=>{const c=s.data;t.value?.uri==c.uri&&(i.value=!0)});y(o)});const u=async function(o){return await a.getPodcastEpisodes(e.itemId,e.provider)};return(o,s)=>(r(),k(D,null,[E(f,{item:t.value},null,8,["item"]),t.value?(r(),p(I,{key:0,itemtype:"podcastepisodes","parent-item":t.value,"show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!0,"show-refresh-button":!0,"load-items":u,"sort-keys":["position","position_desc","name","duration","duration_desc"],"update-available":i.value,title:o.$t("podcast_episodes"),"allow-key-hooks":!0,path:`podcast.${e.itemId}.${e.provider}`,"restore-state":!0,"no-server-side-sorting":!0},null,8,["parent-item","update-available","title","path"])):n("",!0),t.value?(r(),p(v,{key:1,"item-details":t.value},null,8,["item-details"])):n("",!0)],64))}});export{R as default};
