.header.v-toolbar[data-v-56a4abe4]{height:55px;font-family:JetBrains Mono Medium}.header.v-toolbar[data-v-56a4abe4] .v-toolbar__content{height:55px!important;min-height:55px!important;padding-top:0;padding-bottom:0;align-items:center}.header.v-toolbar[data-v-56a4abe4] .v-toolbar-title{margin-inline-start:10px!important}.header.v-toolbar[data-v-56a4abe4] .v-toolbar__prepend{margin-inline-start:12px!important;margin-inline-end:0px!important}.header.v-toolbar>.v-toolbar__content>.v-toolbar__append[data-v-56a4abe4]{margin-inline-end:5px}.header.v-toolbar-default>.v-toolbar__content>.v-toolbar__append[data-v-56a4abe4]{margin-inline-end:10px}.mobile-brand[data-v-56a4abe4]{display:flex;align-items:center;gap:1rem}.mobile-brand-logo[data-v-56a4abe4]{height:30px;width:30px}.mobile-brand-text[data-v-56a4abe4]{font-weight:600;letter-spacing:.5px;margin-top:4px}
