import{F as y,d as k,i as h,G as C,M as m,_ as B}from"./index-HFEfURXv.js";import{d as p,o as V,D as s,e as t,ak as f,B as n,E as a,h as $,b as c,ab as x,H as r,f as v,I as g,_ as R,F as M,M as A,Z as I}from"./lucide-sS6c3snl.js";import{P as E}from"./PanelviewItemCompact-PrcYkefq.js";import{E as P,q as u,g as T,v as N}from"./vuetify-ffr1lJCG.js";const O=p({__name:"Carousel",setup(e){return V(()=>{document.documentElement.style.setProperty("--swiper-navigation-color","primary")}),(d,l)=>{const w=f("swiper");return t(),s(w,{"slides-per-view":n(y)(d.$vuetify.display.width)+.5,"free-mode":!0,navigation:!1,mousewheel:{forceToAxis:!0,releaseOnEdges:!0}},{default:a(()=>[$(d.$slots,"default")]),_:3},8,["slides-per-view"])}}}),z={class:"mr-3"},D={key:0},F={class:"carousel-wrapper"},W=p({__name:"WidgetRow",props:{widgetRow:{},editMode:{type:Boolean},showProviderOnCover:{type:Boolean}},emits:["update:settings"],setup(e,{emit:d}){const l=d;return(w,o)=>{const b=f("swiper-slide");return t(),c("div",{class:x(`widget-row ${e.widgetRow.settings&&!e.widgetRow.settings.enabled?"disabled":""}`)},[r(P,{class:"header",color:"transparent"},{title:a(()=>[v("span",z,R(e.widgetRow.title),1),e.widgetRow.subtitle&&n(h)("bp6")?(t(),s(T,{key:0,inline:"",outlined:"",text:e.widgetRow.subtitle,density:"compact",size:"small"},null,8,["text"])):g("",!0)]),append:a(()=>[e.editMode&&e.widgetRow.settings?(t(),c("div",D,[e.widgetRow.settings.position!==0?(t(),s(u,{key:0,icon:"mdi-chevron-up",class:"enabled",onClick:o[0]||(o[0]=i=>l("update:settings",{...e.widgetRow.settings,position:e.widgetRow.settings.position-1}))})):g("",!0),r(u,{icon:"mdi-chevron-down",onClick:o[1]||(o[1]=i=>l("update:settings",{...e.widgetRow.settings,position:e.widgetRow.settings.position+1}))}),r(u,{icon:e.widgetRow.settings.enabled?"mdi-checkbox-marked":"mdi-checkbox-blank-outline",onClick:o[2]||(o[2]=i=>l("update:settings",{...e.widgetRow.settings,enabled:!e.widgetRow.settings.enabled}))},null,8,["icon"])])):e.widgetRow.provider?(t(),s(k,{key:1,domain:e.widgetRow.provider,size:24},null,8,["domain"])):g("",!0)]),_:1}),v("div",F,[e.widgetRow.items.length>0?(t(),s(O,{key:0},{default:a(()=>[(t(!0),c(M,null,A(e.widgetRow.items,i=>(t(),s(b,{key:i.uri},{default:a(()=>[r(E,{item:i,"show-provider-on-cover":e.showProviderOnCover,"permanent-overlay":![n(m).ALBUM,n(m).TRACK,n(m).RADIO].includes(i.media_type),"is-available":n(C)(i),disabled:e.editMode},null,8,["item","show-provider-on-cover","permanent-overlay","is-available","disabled"])]),_:2},1024))),128))]),_:1})):(t(),s(N,{key:1},{default:a(()=>[I(R(w.$t("no_content")),1)]),_:1}))])],2)}}}),H=B(W,[["__scopeId","data-v-a88771f6"]]);export{H as W};
